All language subtitles for Fog of War 2025

af Afrikaans
ak Akan
sq Albanian
am Amharic
ar Arabic
hy Armenian
az Azerbaijani
eu Basque
be Belarusian
bem Bemba
bn Bengali
bh Bihari
bs Bosnian
br Breton
bg Bulgarian
km Cambodian
ca Catalan
ceb Cebuano
chr Cherokee
ny Chichewa
zh-CN Chinese (Simplified)
zh-TW Chinese (Traditional)
co Corsican
hr Croatian
cs Czech
da Danish
nl Dutch
en English
eo Esperanto
et Estonian
ee Ewe
fo Faroese
tl Filipino
fi Finnish
fr French
fy Frisian
gaa Ga
gl Galician
ka Georgian
de German
el Greek
gn Guarani
gu Gujarati
ht Haitian Creole
ha Hausa
haw Hawaiian
iw Hebrew
hi Hindi
hmn Hmong
hu Hungarian
is Icelandic
ig Igbo
id Indonesian Download
ia Interlingua
ga Irish
it Italian
ja Japanese
jw Javanese
kn Kannada
kk Kazakh
rw Kinyarwanda
rn Kirundi
kg Kongo
ko Korean
kri Krio (Sierra Leone)
ku Kurdish
ckb Kurdish (Soranî)
ky Kyrgyz
lo Laothian
la Latin
lv Latvian
ln Lingala
lt Lithuanian
loz Lozi
lg Luganda
ach Luo
lb Luxembourgish
mk Macedonian
mg Malagasy
ms Malay
ml Malayalam
mt Maltese
mi Maori
mr Marathi
mfe Mauritian Creole
mo Moldavian
mn Mongolian
my Myanmar (Burmese)
sr-ME Montenegrin
ne Nepali
pcm Nigerian Pidgin
nso Northern Sotho
no Norwegian
nn Norwegian (Nynorsk)
oc Occitan
or Oriya
om Oromo
ps Pashto
fa Persian
pl Polish
pt-BR Portuguese (Brazil)
pt Portuguese (Portugal)
pa Punjabi
qu Quechua
ro Romanian
rm Romansh
nyn Runyakitara
ru Russian
sm Samoan
gd Scots Gaelic
sr Serbian
sh Serbo-Croatian
st Sesotho
tn Setswana
crs Seychellois Creole
sn Shona
sd Sindhi
si Sinhalese
sk Slovak
sl Slovenian
so Somali
es Spanish
es-419 Spanish (Latin American)
su Sundanese
sw Swahili
sv Swedish
tg Tajik
ta Tamil
tt Tatar
te Telugu
th Thai
ti Tigrinya
to Tonga
lua Tshiluba
tum Tumbuka
tr Turkish
tk Turkmen
tw Twi
ug Uighur
uk Ukrainian
ur Urdu
uz Uzbek
vi Vietnamese
cy Welsh
wo Wolof
xh Xhosa
yi Yiddish
yo Yoruba
zu Zulu

Original subtitles

(♪♪♪)

SEN DOLAR: Saya terkadang mengalami mimpi buruk

Bahwa Jerman menangkapmu dan menempatkan Anda di sebuah kamp.

terkadang lebih buruk.

terkadang dalam mimpi, Aku berteriak untukmu

untuk melakukan apa pun itu Anda perlu melakukannya.

untuk bergabung dengan mereka.

Lakukan apapun yang harus Anda lakukan untuk tetap hidup.

Gene: (Over Radio) mereka datang!

(Percakapan radio yang tidak jelas)

Gene: (Over Radio) Comin 'in--

(Penembakan pesawat)

Joey, tidak!

Travis: (Over Radio Parasut!

Gene: (Pidato tidak jelas)

Mayday! Mayday!

(Obrolan radio tidak jelas)

Travis: Jaminan! Jaminan!

(Airplane berputar di jarak)

(Erangan gen)

(♪♪♪)

(Percakapan dalam bahasa Jerman)

(Anjing menggonggong)

Travis: Gen.

Gen.

Gen, di sini.

(CELANA)

Kamu oke?

Sepertinya Anda lakukan Jauh lebih baik dari saya, saudara.

Biarkan aku melihat. (Erangan)

Gene: Oke.

Bisakah kamu pindah?

Saya pikir itu meleset vital saya, Tapi aku akan segera membutuhkan petugas medis.

Gene: Oke, oke. Kamu akan baik -baik saja.

Saya pikir pantai beberapa ratus meter seperti itu.

Kami akan mencoba dan temukan beberapa persahabatan,

Dan keluar dari sini.

Dimana Joey?

Dia ada di sana.

Tetap di sini, saya akan segera kembali.

Saya tidak pergi ke mana pun.

Gene: Joey. Joey. Saya di sini, sobat.

Saya di sini. Kamu oke?

Hai.

Hei, Joey.

(CELANA)

Maaf, sobat.

(Tentara berteriak dalam bahasa Jerman di JARAK)

Maaf, sobat. Saya minta maaf.

(CELANA)

Travis: Hei, hei, hei, hei, hei!

Kembali, kembali.

Tolong, tolong, tolong, Tolong, tolong.

Tolong, saya punya istri.

Saya punya istri. Saya punya istri. Saya punya istri.

Prajurit 1: (Berbicara bahasa Jerman)

Travis: Saya punya istri.

Saya punya anak.

(Anjing menggonggong)

(Tembakan)

(♪♪♪)

(Kunci klik)

RESEPSIONIS: Pergilah ke dalam, Dia mengharapkanmu.

(Mengetuk pintu)

Itu terbuka.

Pak, Anda ingin melihat saya?

Masterman: Oh, McVean.

Ayo masuk, tutup pintu.

Bagaimana pelatihannya terjadi di lapangan?

Ya, saya pikir kami memiliki beberapa Rekrutmen kami yang paling menjanjikan.

Bagus.

Kita akan membutuhkannya.

Apa maksudmu?

Ah, rencana rahasia

untuk invasi operasional telah dikompromikan.

Rencana untuk situs pendaratan, posisi kapal,

Waktu peluncuran, semuanya dicuri.

Kami menghentikan semua operasi OSS di Eropa sampai pemberitahuan lebih lanjut.

Dan SOE dan OS Inggris setuju.

Jika Jerman mendapatkan tangan mereka tentang rencana itu,

Kami bisa kehilangan pijakan kami di Prancis.

Dan sangat mungkin perang.

Yesus Kristus.

(Mendesah)

(Mengetuk pintu)

Masterman: Datang.

Ah, salah satu rekrutan top Kami hanya membicarakannya.

Pak.

Masterman: Agen Duncolm.

Nama Anda sudah banyak datang belakangan ini.

Saya mengerti tunangan Anda ditembak jatuh ke Prancis.

Ya, tuan, perlawanan menemukannya,

membantunya ke luar negeri beberapa minggu yang lalu.

Saya belum melihatnya

Sejak dia bertulur di Pennsylvania.

Anda harus saling merindukan sangat banyak.

Ya, Pak.

Kertas keluar rumah sakit.

Anda bekerja lebih keras dari siapa pun di sini.

Tunangan Anda membutuhkan Anda.

Dan sejujurnya, Anda bisa menggunakan istirahat.

SEN DOLAR: Saya tidak tahu harus berkata apa.

Terima kasih, Pak.

Dan penyebaran saya di luar negeri?

Nah, hari itu mungkin sangat baik.

Tapi sementara itu, pertimbangkan ini adalah berkah sementara

di waktu di mana Benar -benar tidak ada.

Terima kasih, Pak.

(Pintu terbuka dan ditutup)

McVean: Haruskah kita benar -benar memberi Agen Duncolm pergi sekarang?

Masterman: McVean, apa yang Anda ketahui Tentang tunangan Penny?

Prajurit di Tongkat: (Pidato tidak jelas)

Selamat pagi, Pak.

-Nurse: Bagaimana rasa sakitnya? -Gene: (ucapan tidak jelas)

PERAWAT: Oke, tapi pada skala 1 hingga 10?

-Gene: Empat. -Nurse: Oke.

-Gene: Saya merasa kuat. -Mcvean: Letnan Lewis?

Saya Kapten McVean.

Ini rekan saya.

Alexander: Agen Alexander, OSS.

Apakah Anda keberatan jika kami berbicara Secara pribadi sejenak?

Ya, tentu.

(Mendengus)

McVean: Bagaimana Anda bertahan?

Saya akan jauh lebih baik Saat saya keluar dari sini.

Alexander: Saya akan mengatakan Anda pria yang beruntung.

Bagaimana bisa?

Alexander: Anda beruntung masih hidup.

Itu bisa jauh lebih buruk.

Tunangan Anda Penny Duncolm ...

Dia baik -baik saja?

McVean: Baik -baik saja.

Anda sadar pamannya memiliki properti di utara?

Gene: Ya, dia tumbuh di sana.

Beberapa hari yang lalu, ada Operasi yang sangat sensitif

itu dikompromikan.

Sejak itu, kecerdasan telah dicegat

beberapa transmisi yang tidak biasa,

kebetulan datang dari daerah dekat pertanian.

Alexander: Kami membutuhkan seseorang di atas sana untuk memeriksa semuanya.

Lihat apa, tepatnya?

Lihatlah ke sekeliling, Laporkan kembali tentang hal yang tidak biasa.

Apakah Penny tahu?

Dia disediakan cuti untuk pergi mengunjungi bibinya dan pamannya.

Sejauh itu sejauh ini.

Membuatnya menjalankan operasi

hanya akan membawa kekhawatiran yang tidak perlu.

Alexander: Dia agen yang luar biasa.

Mereka akan mengajukan terlalu banyak pertanyaan.

Anda mengerti itu, kan?

(♪♪♪)

McVean: Dengar, Nak.

Saya tahu seperti apa

kehilangan orang yang dicintai dalam perang.

Kemarahannya.

Rasa malu.

Beginilah cara Anda melawan.

Beginilah cara Anda melakukan bagian Anda

dan masih melayani ke negara ini.

Anda meminta saya untuk berbohong kepada tunangan saya dan keluarganya.

Tidak berbohong.

Untuk melindungi.

Anda tidak memata -matai mereka.

Mungkin ada musuh berbahaya mengintai.

Dan mereka bahkan tidak mengetahuinya.

Apakah saya punya pilihan?

(Mendesah)

Alexander: Terima kasih, Letnan.

Penyiar: (pada sistem PA) perhatian (ucapan tidak jelas)

(♪♪♪)

SEN DOLAR: Permisi, tuan. Kursi ini sudah dipesan?

Ya, itu sebenarnya.

Sen dolar.

Gen.

Gene: Aku, uh ...

Saya tidak percaya.

Saya pikir kita mungkin tidak pernah ...

SEN DOLAR: Saya juga.

(Ciuman)

Gene: Jadi apa yang saya dengar tentang Anda

menjadi yang penuh Agen Lapangan OSS?

Apakah itu benar?

(Terkekeh)

Nah, kita semua memiliki bagian kita bermain dalam perang ini.

Kurasa itu milikku.

Mm.

Selalu sangat sederhana.

Tapi selalu berprestasi.

(Terkekeh)

Aku bangga padamu.

Terima kasih.

Saya tidak sabar untuk memperkenalkan Anda Kepada Paman Bob dan Bibi Maude.

Hmm.

Sebagai tunangan saya.

Pahlawan perang.

Penyiar: (pada sistem PA) Perhatian Penumpang,

245 Express to Boston (Pidato tidak jelas)

-That akan menjadi kita. -Oh.

Penyiar: (pada sistem PA) ... sekarang tiba pada platform tiga.

Gene: Jadi saya berkata, " Anda tahu, Saya tahu bahwa Anda tahu bahwa

(Pidato tidak jelas) "

(♪♪♪)

SEN DOLAR: Dan di musim panas,

Saya akan berjalan -jalan di air Saat matahari terbenam.

Pemandangan yang sangat indah. Ini akan membuat Anda terengah -engah.

Hmm.

Saya-- Saya-- Saya tidak sabar untuk melihatnya.

Apa itu?

Nah, hanya saja saya tahu Betapa Anda mencintai tempat ini.

Saya berharap kita pergi dalam keadaan yang berbeda.

Jika Anda memikirkannya,

Kami mendapatkan kesempatan meninggalkan dunia.

Semua ketakutan,

dan ketidakpastian.

Saya sangat berterima kasih untuk itu.

Anda benar.

Saya juga.

(Melatih wirring)

SEN DOLAR: di pagi hari,

Kabut sangat tebal sehingga Anda hampir tidak bisa melihat.

tapi kemudian kabut terangkat, dan sangat indah.

Anda akan menyukainya di sana.

(♪♪♪)

Jocelyn: Aku akan mengambil tasmu.

Gene: Terima kasih.

Bob: Itu dia!

SEN DOLAR: Paman Bob!

Bob: Itu dia.

Biarkan saya melihat Anda.

-Aku merindukanmu. -Anda terlihat baik -baik saja.

Anda pasti sangat senang kembali ke rumah.

-Apakah kamu? -Ya, sangat.

Ini pasti gen.

Uh, ya, Paman Bob. Ini adalah Gene Lewis.

Itu menyenangkan Untuk bertemu denganmu, Pak.

-Terima kasih karena kami memiliki kami. -Anda sangat disambut.

(Terkekeh)

Gene: Anda punya properti yang sangat indah.

Bob: Terima kasih.

Oh, dan tepat di sana,

Sekitar seratus meter, adalah lautan.

-Gene: Luar biasa. -Jock: Ya.

Cukup menggigil Anda ke tulang.

Pikirkan saja itu benar di seberang lautan itu

adalah ribuan orang Jerman hanya ...

hanya gatal ' untuk mendapatkan kami.

Bob: Datang. Jock: Storm bisa mematahkannya menit.

Bob: Atlet dan jocelyn

memiliki tempat tinggalnya sendiri di properti.

-Mereka membantu kami. -Gene: Begitu.

SEN DOLAR: Yah, mereka punya tangan penuh di Eropa.

Tidak masuk akal dalam mereka membawa perang bagi kita.

Um, aku akan menyapa Bibi Maude.

Mengapa Anda tidak memberi gen Tur?

Bob: Kedengarannya seperti ide yang bagus.

Sangat.

Dengan cara ini. Aku akan menunjukkanmu.

Eh, sen, apakah maude memberitahumu Kami memiliki perekrutan baru?

Uh, ya. Viktor, bukan?

Ya, seorang pengungsi dari Eropa.

SEN DOLAR: Satu lagi dari proyek gairahnya?

-BOB: Anda tahu bagaimana dia. -Benar.

Bob: Dia hebat Membantu Maude di sekitar rumah.

-Terapi halo. -Penny: Saya akan.

Dengan cara ini, gen.

Jadi kami mendapat sekitar 100 hektar.

Eh, seperti yang Anda lihat, kami punya-- Kami memiliki domba.

Beberapa ternak.

Satu perhentian terakhir.

Saya hanya perlu mengambil sesuatu dari gudang.

-Mengaja langkah Anda. -Uh, terima kasih.

-Mengaja langkah Anda di sana. -Gene: Ya.

Oh, wow.

Siapa, eh, pelukis?

Bob: Nah, saya mencoba -coba di sana -sini.

Saya dulu berurusan dengan impor langka, Tapi sejak perang,

Nah, lakukan saja apa yang saya bisa untuk memberi makan semua orang

sampai hal ini sudah berakhir.

Bagaimana denganmu? Bagaimana kabar keluarga Anda?

Oh, yah, sebenarnya, itu, eh, hanya aku.

Kedua orang tua saya lewat saat Saya di sekolah menengah.

Bob: Oh.

Brengsek! Maafkan aku.

-Penny memberitahuku. -Tidak apa-apa.

Bob: Saya sangat menyesal.

Saya tahu lebih baik.

Eh, itu kecelakaan mobil.

-Apakah itu benar? -Itu benar.

-Anda berasal dari Ohio? -Gene: mm-hmm.

Nah, kita tidak akan kelaparan malam ini.

Sayang?

Sayang?

Saya membawakan Anda kelinci dan seorang letnan.

Maude: Ah!

Oh!

Nah, lihatmu.

Penny benar. Anda pria yang sangat tampan.

-Gene: Gene Lewis. -Maude.

Sangat senang memilikimu.

Gene: Senang berkenalan dengan Anda. Terima kasih.

Kemana saja kamu?

Oh, um, di gudang. Dimana Penny?

Maude: Dia ada di kamarnya Membongkar tasnya.

Anda salah satu dari sedikit istimewa.

Dia tidak pernah membiarkan saya melihat lukisannya

sampai mereka selesai.

Anda pasti membuatnya terkesan.

Saya baru saja membuat kopi. Apakah Anda ingin cangkir yang enak?

Uh, tidak, Bu. Saya baik -baik saja, terima kasih.

Oh, oke.

Nah, satu untuk kekasihku.

Terima kasih, sayangku.

(Ciuman)

Maude: Izinkan saya menunjukkan Anda ke atas ke kamar Anda.

Saya yakin berharap Penny memperingatkan Anda tentang cuaca di sini.

Setelah kabut tebal ini masuk, Benar -benar tidak ada apa -apa untuk itu

Kecuali menyalakan api dan mengenakan ketel.

(Terkekeh) Kedengarannya menawan.

Maude: Aku tidak bisa memberitahumu berapa kali

Kami telah terdampar kembali dari kota.

Setiap penginapan di sepanjang jalan mengenal kami Nah sekarang.

Anda memiliki selera yang sangat eklektik untuk rumah pertanian.

Oh, yah, saat kami pindah ke sini,

Saya merasa bertekad untuk membawa Beberapa kehidupan kota kita bersama kita.

Tentu saja, saya tidak bisa menyerah buku saya.

Penny bilang kau parsial ke Carl Jung.

-Apakah itu benar? -Maude: Ya.

Sebenarnya, saya bagian dari kelompok kecil informal

Acolytes Dr. Jung.

Marie-Louise von Franz, Joseph Campbell.

Semua pekerjaan kami memiliki kesamaan.

Saya sebenarnya menulis disertasi saya

pada arketipe pahlawan Mitos Norse

terkait dengan universal tidak sadar.

(Terkekeh)

Nah, kedengarannya menarik, tapi benar -benar di atas kepalaku.

Maude: Tidak, Anda akan menyukainya

Karena Anda akan berhubungan Sebagai seorang prajurit.

Ada begitu banyak kekuatan kisah -kisah itu.

Jadi, ini di sini adalah kamar Viktor, Dan milikmu akan ada di sana.

-Terima kasih lagi. -Maude: Sama -sama.

Jika Anda membutuhkan sesuatu, Beri tahu saya.

Sampai jumpa saat makan.

Sampai jumpa.

(♪♪♪)

Apakah Anda ingin bantuan Membongkar?

Oh. Tidak, tidak apa -apa.

Saya hanya ingin menempatkan Beberapa hal jauhnya.

Saya benar -benar berpikir tentang pergi berjalan -jalan sedikit

-Untuk meregangkan kaki saya. -Yeah, um--

Gene: Jika Anda ingin bergabung dengan saya.

Apakah Anda keberatan Jika saya melakukan pemeriksaan hujan?

Saya hanya belum melihat Paman Bob dan Bibi Maude sebentar lagi.

Aku benci membuat mereka menunggu.

Ya, tentu saja.

SEN DOLAR: Bagaimanapun, kami akan membuat Anda bosan.

Anda harus pergi.

Ya, ya.

Oke, baiklah.

Dan itu akan memberi saya banyak waktu untuk membicarakan Anda.

Apa yang akan kamu katakan?

-Meng itu yang terburuk. -Paling buruk.

Tidak ada yang buruk tentang saya.

(Cekikikan)

Gene: Siapa ini?

Apakah itu kamu dan ibumu?

Itu seharusnya tidak ada di sini.

Aku akan selesai membongkar.

Oke.

Maude: Nah, bagaimana menurut Anda, Sayang?

Nah, dari apa yang dikatakan Penny, Dia tampak kecewa.

Sedikit rusak.

Ya, saya pikir pengalamannya

telah melakukan sesuatu padanya.

Bob: Mungkin telah membukanya.

Maude: Mungkin.

Tidak setiap kejahatan datang menghancurkan kami.

Tidak tidak tidak.

Maude: Tapi ini sen yang kita bicarakan.

Saya pikir dia masih muda.

Dan saya berharap dia tidak hanya berpikir dengan hatinya,

Tapi dengan kepalanya.

Bob: Mungkin.

Maksudku, ini ...

Ini adalah keputusan besar.

Itu dia.

Halo.

Maude: Halo.

Nah, bagaimana menurut Anda?

Maude: I-- i-- saya pikir Bahwa dia ternyata sangat baik.

Saya bisa melihat apa yang Anda lihat dalam dirinya.

Ya, ya.

Dia sangat, eh, sangat sopan.

Um, sangat menyenangkan.

Saya belum melihat Di belakang topeng,

Tapi saya menganggap Anda punya.

Ya, saya punya.

Itu sangat berarti Bahwa kamu menyukainya.

(Terkekeh)

Seperti dia?

Saya tidak mengatakan saya menyukainya.

Jangan menaruh kata -kata di mulutku, Sen dolar.

Maude: Baiklah, Bob. Ayo sekarang.

Bob: Maksudku, kita harus jujur.

Maude: Bob.

Anda tahu betapa pentingnya keputusan ini.

Ya?

Ya.

Bob: Bagus.

(♪♪♪)

(Wirring mobil)

Gene Lewis.

Viktor.

Anda harus menjadi pilot

Bob dan Maude telah dibicarakan.

Jadi dari mana asalmu, Vik?

Viktor: Belgia.

Dan itu Viktor, tolong.

Maaf.

Berhati -hatilah berjalan di malam hari.

Melalui hutan di sana.

Ada tebing tentang

bahwa Anda bisa berjalan

dan tidak pernah menyadari mereka ada di sana.

Terima kasih atas perhatiannya.

Viktor: Jangan tinggal di sini terlalu lama.

Seperti yang saya katakan, itu bisa berbahaya.

(Mobil Shirs)

Maude: "Orang -orang melihat ilahi

di dunia alami di sekitar mereka,

dalam ritme musim,

dan dalam pola bintang -bintang.

mereka berusaha mempertahankan perasaan keseimbangan dan harmoni

dengan dunia suci ini,

melalui ritual dan praktik

Itu mencerminkan pemahaman mereka

ordo kosmik. "

Pandangan dunia yang lezat.

SEN DOLAR: Jadi, Viktor, saya dengar Anda adalah pelaut yang fantastis.

Viktor: Tidak tidak tidak.

Saya baik -baik saja.

Tapi saya sangat menyukai laut.

Berlayar air ini sulit.

Bob: Bukan untuk pro seperti Anda.

Seorang pemula seperti saya, meskipun,

Nah, tanpa mercusuar di dekat sini,

Saya tidak ingin mencobanya sendiri.

Tidak ada di sekitar sini.

SEN DOLAR: Itu dia.

I, eh, Hampir tidak berhasil kembali.

Semua berjalan begitu cepat.

Beri pria itu beberapa wiski.

Gene: Terima kasih.

Bob: Jadi bagaimana denganmu, Gene?

Apakah Anda berbakat di laut Saat Anda berada di udara?

Oh, eh, tidak. Sama sekali tidak.

Justru sebaliknya.

Maude: Oh, tidak perlu bersikap sederhana di rumah ini.

Saya yakin dengan keterampilan Anda sebagai pilot,

Anda akan berlayar seperti itu.

(Gene terkekeh)

Gene: Terima kasih.

Jadi, apakah ini milikmu, Bob?

Oh, tidak, ini sudah tua-- lukisan lama.

Itu, eh, Itu perkebunan keluarga lama kami.

Kita bisa melacak nenek moyang kita kembali ke

Saat viking pertama Pesisir Skotlandia yang digerebek.

Di kedua sisi.

Bob: Itu benar.

SEN DOLAR: Aku tidak memilikimu

Ketika saya mengatakan kami berasal Garis panjang sarang Skotlandia.

Kakek saya adalah seorang sosialis.

Dia menggunakan sebagian besar Uang keluarga

dan berimigrasi ke negara bagian di akhir 1800 -an.

Dia adalah seorang pria prinsip.

-Maude: Benar. -Penny: Benar.

Biarkan anjing tidur berbohong.

(Terkekeh)

Bagaimana denganmu, Viktor?

Bagaimana Anda datang untuk menemukan diri Anda sendiri Sepanjang jalan di sini?

Kamu tahu, Itu cerita yang sangat panjang.

Bagaimana dengan versi pendeknya?

Kembali ke rumah, saya tidak mampu untuk mendukung keluarga saya.

Belgia kecil dan pekerjaan langka.

Jadi saya bepergian.

Membuatnya tepat di luar Belgia

Saat negara itu jatuh ke Nazi.

Hmm.

Apakah Anda bisa Kirimkan uang sekarang?

Saya belum mendengar kabar dari mereka sejak itu.

Dimana Cincin Pernikahan Anda?

Oh, itu menjadi sangat dingin, Sayang.

Haruskah kita mendapatkan lagi--

Saya akan mendapatkan beberapa log lagi untuk api.

Dan, eh, beberapa kentang.

Penny, bisakah kamu membantu kami?

Oke, tentu saja.

(♪♪♪)

Halo.

Hai.

Hanya ingin mampir dan mengucapkan selamat malam.

Datang.

Apa yang kamu kerjakan?

Oh, tidak ada.

Hanya Doodlin '.

Oh.

Seorang seniman, ya?

Apakah Bob menginspirasi Anda?

Ya.

Ya, saya ingin belajar untuk melukis kapal

dan perkebunan keluarga tua.

(Terkekeh)

Saya berharap mereka tidak terlalu banyak.

Maksud saya, saya tahu mereka punya

kepribadian yang sangat khas.

Oh.

Ya, tentu saja, tapi mereka sangat orang baik.

Sangat pintar juga.

Terutama Maude.

Ya.

Tapi saya tidak tahu apa dia Bicara sekitar separuh waktu.

Saya juga tidak.

(Keduanya terkekeh)

Saya sangat beruntung memilikinya. Ya.

Hmm.

Mereka satu -satunya keluarga sejati Saya telah pergi.

Jadi...

... Saya ingin melihat mereka lagi.

Anda tahu, untuk berjaga -jaga.

Jika apa?

Nah, jika-- Jika perang belum segera berakhir,

Saya harus kembali ke luar negeri pada akhirnya.

Jadi...

Sen dolar,

Tidak ada yang akan terjadi untukmu.

Ya, Anda mungkin benar.

Saya tidak tahan untuk memikirkannya tidak bersamamu.

(Berciuman)

Seharusnya tidak, saya pikir.

Baik, saya-- i-- Saya tidak ingin tidak menghormati

Bob dan Maude.

Oh.

Di rumah mereka.

Ya.

Benar?

Ya, Anda benar.

(Mendesah)

Kita mungkin harus Pergi ke luar.

Tidak, saya pikir Anda hanya perlu menunggu.

(Mendesah)

Selamanya dan sehari, selamanya.

(Penny terkekeh)

Selamat malam, cintaku.

Mimpi indah.

(Pintu ditutup di latar belakang)

(♪♪♪)

Jika mereka menikah di pertanian, Apakah Anda pikir mereka akan membiarkan kami datang?

Jock: Aku tidak tahu. Mungkin.

Bisakah saya mendapatkan gaun baru Jika mereka melakukannya?

Kita lihat, sayang.

(♪♪♪)

Hei, eh, Saya ingin memeriksa sesuatu.

Mari ikut saya.

(♪♪♪)

(Jeep Wirring)

Anda bukan dari sekitar sini.

Gene: Uh, tidak, tuan.

Saya tinggal bersama Bob dan Maude.

Gen. Gene Lewis.

Saya bertunangan dengan keponakan mereka Sen dolar.

Oh, selamat!

Keluarga yang cantik untuk dinikahi.

Sebenarnya sebuah wasiat dengan semua yang telah mereka lalui.

Uh, maafkan aku.

Sebenarnya, saya tidak berpikir Saya mengerti.

Quinn: Penny tidak memberitahumu?

Yah, itu bukan urusan saya Bagaimanapun.

Ini adalah Sersan Collins. Saya Kapten Quinn.

Di sini sendirian?

Tidak, saya benar -benar keluar untuk melihat ...

Dia ada di sini semenit yang lalu.

Quinn: Apakah pria Viktor itu? The Lodger?

Saya terus mencoba berbicara dengannya, Dan dia tidak pernah ada.

Sulit untuk dijabarkan.

Ya, saya tahu apa yang Anda maksud.

Apa yang terjadi dengan kaki Anda?

Saya terluka di Prancis.

Quinn: Hmm.

Kecelakaan pesawat?

-Anda sudah tahu? -Quinn: Saya lakukan.

Kami memiliki koneksi bersama.

McVean.

Dia meminta laporan.

Saya benar -benar menulis beberapa hal di bawah.

Tentang Penginapan itu, Viktor.

Um, belum ada yang konkret, Tapi Anda tahu, itu--

Kami hanya memiliki beberapa interaksi, Tapi semuanya ada di sana.

Ini adalah telepon untuk berkemah.

Jika Anda membutuhkan sesuatu, apapun, Telepon aku.

Akan melakukannya, terima kasih.

Quinn: Jaga kecerdasan Anda tentang Anda.

Sangat.

(Jeep Wirring)

Jock: Siapa itu?

Gene: Kemana kamu pergi?

Oh, berhati -hati dari semua domba.

Kapten penjaga negara bagian ada di sini.

Oh, patroli rutin.

Jadi apa yang membawamu ke sini?

Yah, aku hopin ' Anda bisa membawa saya ke kota.

Jadi saya bisa mengambil beberapa hal Saya runnin 'low on

dan keluar dari rumah.

Ya. Ya, tentu.

Kami semua selesai di sini. Saya bisa mengemas ini nanti.

-Jock: naik. -Terima kasih.

Penjaga negara.

Dia menyebutkan sesuatu tentang semua yang buruk itu terjadi

ke keluarga Penny.

Bagaimana dengan itu?

Apakah Anda tahu Apa yang dia bicarakan?

-Memadi kematian ibunya. -Jocelyn.

Apa?

Jocelyn: Anda tidak tahu?

Gene: Dia tidak berbicara tentang orang tuanya.

Jocelyn (OS): Maude praktis membesarkannya

sebagai miliknya sejak dia seorang gadis muda.

-Bagaimana dia mati? -Kami-- kami tidak benar-benar tahu.

Jock: Orang hanya mengatakan bahwa dia pergi berjalan -jalan suatu malam,

Dan kemudian hari berikutnya Mereka menemukan tubuhnya

di dasar tebing, oleh air di atas bebatuan.

Orang mengatakan itu Dia tidak pernah memulihkan diri

dari ayah Penny Dyin ' Perang Besar.

Itu tragedi nyata.

Saat itulah Bob dan Maude membawanya masuk

dan membesarkannya sebagai milik mereka.

Jadi jangan beri tahu siapa pun Kami juga memberitahumu.

Bob sering memperingatkan saya tentang pernah

Membawa itu di depan dari Penny.

Hang-- Tunggu.

Ada yang salah.

(Pintu terbuka, tutup)

Jock: Ada yang salah dengan mesin.

Kenapa kalian tidak adil Duduklah,

Saya akan mengurus ini.

Bob: Bagaimana kakinya bertahan?

Anda tahu, lukanya, apakah itu penyembuhan?

Uh, maksudku, tidak apa -apa.

Tidak sembuh, tapi tidak apa -apa.

Ya, hal -hal ini membutuhkan waktu.

BENAR.

Saya mencoba, Penny.

Saya-- Saya sangat mencoba.

(♪♪♪)

Tapi saya tidak melihat apa Anda melihat pria ini.

Anda tidak bertemu dengannya yang terbaik.

Saya pikir Prancis mengubahnya.

Dia hanya ...

Menurut saya Semuanya memukulnya sekarang.

Aku hanya ingin kamu bersama seorang pria

substansi, dan kepercayaan diri,

dan visi.

Anda harus mempercayai pria ini dengan hidupmu.

Dan saya lakukan.

Dia dapat dipercaya.

Dia benar -benar.

Hanya-- beri dia waktu.

Anda akan melihat apa yang saya lihat.

Dia berkomitmen.

Nah, dia jatuh cinta padamu.

(Terkekeh)

-Rght. -Itu komitmen.

-Gene: Oh. -Penny: Oh, Gene, itu dia.

Semuanya baik -baik saja?

Maaf, Saya baru saja akan masuk.

SEN DOLAR: Oh, tidak, tidak. Menyelesaikan.

Saya tidak keberatan.

-Gene: Hai. -Penny: Hai.

Jadi dari mana saja kamu?

Oh, aku, uh ...

Saya bertanya pada Jock untuk membawaku ke kota, tapi ...

Biarkan saya menebak.

Anda tidak berhasil.

Benar.

(Terkekeh)

Jock's memiliki beberapa run-in dengan hukum.

Mabuk dan tidak teratur.

Saat ini, dia akan melakukan apapun untuk menghindari pergi ke kota

dan godaan.

Jadi...

Itu tidak mengejutkan saya untuk beberapa alasan.

(Terkekeh)

Ya, saya tahu apa yang Anda maksud.

(Terkekeh)

Tampilannya.

Hei, Stern.

(Keduanya tertawa)

Atlet berkata dia melihatmu berbicara dengan penjaga negara.

Oh, dia baru saja mampir untuk satu menit.

Um, dia bertanya tentang Viktor, Sebenarnya.

Dia tampak khawatir seseorang yang tinggal di sini

siapa yang belum dia temui.

Hmm.

Yah, saya yakin itu hanya kesalahpahaman.

-Ayo. -Baiklah. Ya.

(Mendengus)

(♪♪♪)

Sangat bagus Havin 'Penny Back.

Bob dan Maude hanya menyala Kapanpun dia ada di sekitar.

Ya, dia berbicara tentang tempat ini banyak.

Jock: Saya pikir ini adalah yang terpanjang Dia pernah pergi.

Bagaimana Anda dan Penny bertemu?

Itu di Inggris, Setelah dia melarikan diri dari Paris.

Cinta pada pandangan pertama?

Tidak, tidak persis.

Saya mengajaknya berkali -kali, Saya pikir perang akan berakhir

Sebelum dia mengatakan ya.

Untungnya, tekad saya lebih kuat dari miliknya.

Apa yang dia lakukan di Paris?

Bagaimana denganmu, Viktor?

Pasti sulit karena Jauh dari rumah.

Dimana itu lagi?

-Belgia. -Gene: Belgia.

Tidak Antwerp kebetulan?

Saya.

Ayah saya ditempatkan di sana

untuk waktu yang singkat Setelah perang terakhir.

Dia memberitahuku semua tentang klub malam ini.

Kucing Hitam.

Anda harus mengetahuinya.

TIDAK?

Uh, dia berkata siapa pun Siapa yang pernah menginjak kaki di Antwerp

akan tahu tentang Klub Kucing Hitam.

Viktor: Tentu saja.

Tempat yang indah. Kucing Hitam.

Ya.

Tidak, tunggu.

Itu ghent.

Ayah saya ditempatkan di ghent.

(Erangan)

Jock: Gene, kamu baik -baik saja?

Apa yang telah terjadi?

Pasti tergelincir.

Apakah kamu baik -baik saja?

(Pintu terbuka dan ditutup)

(Jalan kaki)

SEN DOLAR: Hei, hon. Kembali dari gudang?

Anda pasti bersenang -senang Keluar dari rumah.

Bagaimana?

Nah, Anda tahu,

selain hampir tertusuk oleh ember alat jatuh,

kamu benar.

-Itu menyenangkan. -OH, tidak. Apakah kamu baik -baik saja?

Gene: Ya, tidak, saya baik -baik saja. Itu hanya merindukanku.

Menggedor lutut saya mencoba menghindar Namun, keluar dari jalan.

Saya tepat di depan Viktor.

Kejutan.

Saya yakin Itu hanya kecelakaan.

Ya, mungkin.

Anda tidak menyarankan Dia melakukannya dengan sengaja, kan?

Gene: TIDAK.

Tidak tepat.

Hanya ada sesuatu tentang pria ini yang tidak saya percayai.

Maude: Halo.

Saya sangat menyesal. Butuh selamanya di perpustakaan.

Mereka tidak mau untuk membiarkan saya membawa pulang

edisi asing mereka yang berharga,

Tapi akhirnya saya berhasil. (Terkekeh)

Bagaimanapun, kami akan membuat jalan kami ke kota

dan harus kembali ke rumah dalam dua hari,

Selama kabut berlaku.

Tapi Anda tidak pernah tahu.

Ini bukan pertama kalinya Kami terjebak.

Apakah ada cara Saya bisa membantu mereka di luar sana?

Oh, saya pikir Mereka mendapatkannya di bawah kendali.

Mengapa kalian tidak berdua cinta menghabiskan sedikit waktu bersama?

SEN DOLAR: Ya, bagaimana kalau kita pergi untuk jalan itu?

Membangun kekuatan kaki Anda?

(♪♪♪)

Kedengarannya bagus.

(♪♪♪)

Wow, itu benar -benar indah Di Sini.

Mm-hmm.

Terkadang saya berpikir itu akan menjadi pelarian yang sempurna.

Sembunyikan di sini sampai perang berakhir.

Kalau saja.

SEN DOLAR: Maksud saya, Apa yang bahkan kita perjuangkan?

Itu bukan perang kita.

Setidaknya, bukan di Eropa.

Gene: Apa yang kamu bicarakan?

Anda tidak bermaksud begitu, bukan?

No I...

Saya tidak bermaksud seperti itu.

Bagaimana maksudmu?

Saya hanya-- Saya hanya bermaksud itu

Saya telah melihat apa yang kami mampu.

Saya tidak yakin pihak kami semuanya bagus juga.

(Mendesah)

Tentu saja tidak, Penny.

Tapi apa yang kita lawan adalah sesuatu yang lain.

-Penny: Ya. -Ini kejahatan murni.

SEN DOLAR: Saya tahu, saya tahu. Tentu saja.

Anda benar.

Terkadang hanya sampai ke saya.

Semua kematian.

Semua rahasia.

Dan saya-- saya hanya berharap Kami telah bertemu sebelumnya semua ini.

Saya senang kami bertemu sama sekali.

(Ciuman)

Saya juga.

Anda tahu apa yang hebat tentang tempat ini?

Hmm?

Tidak ada orang di sekitar untuk menjadi tidak dihargai.

Oke.

(Terkekeh)

(Berciuman)

(♪♪♪)

SEN DOLAR: (Pidato tidak jelas)

Oh, tidak.

Sesuatu.

Lipstik?

Ya.

(Keduanya tertawa)

SEN DOLAR: (Pidato tidak jelas)

(♪♪♪)

Lapar?

Darimana semua makanan ini berasal?

Viktor: Apa maksudmu?

Ini adalah ransum selama seminggu, setidaknya.

Dan?

-Dan ilegal. -Tidak ada baiknya.

Gene: Tidak baik, Viktor.

Keluarga membutuhkan makanan ini.

Dimana kamu mendapatkannya?

Apa semua ini?

Viktor?

Itu seharusnya Sebenarnya persembahan damai.

Dimana kamu mendapatkannya?

Seorang petani yang bekerja untuk saya

terkadang membayar saya dari stoknya.

Sosis, telur, bacon, hal semacam itu.

Saya akan membagikannya denganmu.

SEN DOLAR: Terima kasih, Viktor.

Kedengarannya bagus.

Hei, tentang apa itu?

Anda tidak benar -benar membelinya, apakah kamu?

Penny: Apa? -Tidak ada Sepertinya aneh bagimu?

Tahan suaramu.

-Dia penimbunan makanan, sen. -Penny: Oke.

Petani tidak seharusnya Berikan saja itu.

SEN DOLAR: Dia berbagi dengan kami.

Dia baik -baik saja.

Bob mempercayai Viktor,

Dan itu seharusnya Cukup untuk kita, kan?

Benar.

Tapi aku tidak makan makanan itu.

Bagus.

(Jalan kaki)

(Puffs Smoke)

SEN DOLAR: Mmm, makanannya lezat, Viktor.

Terima kasih.

Ya, terima kasih, Vik.

(Puffs Smoke)

(♪♪♪)

(CELANA)

(DENGKUR)

Gene: Sen dolar!

Penny, tidak! TIDAK!

Soldier 2: (Berbicara bahasa Jerman)

(CELANA)

(Mendesah)

(♪♪♪)

(Tombol Mengklik)

(♪♪♪)

(CELANA)

(♪♪♪)

(SUARA TEMBAKAN)

(♪♪♪)

Maaf jika saya membangunkan Anda.

Anda mungkin punya yang lain tertipu,

Bukan aku.

Anda mendengar saya?

Apakah kita punya masalah lain di sini?

Sesuatu yang tidak saya sadari?

Anda benar -benar berpikir saya tidak tahu, Viktor?

Tahu apa?

Apa yang sedang kamu lakukan?

Siapa yang Anda coba untuk dihubungi Di radio itu tadi malam?

Mendengarkan.

Saya bisa menjelaskan.

Ya, saya pikir Anda lebih baik.

Tidak ada lagi kebohongan.

Saya mencoba menjangkau istri saya.

Perlawanan di Prancis berjanji mereka akan menemukannya.

Saya tidak ada lagi kebohongan!

Saya tidak berbohong.

Gene: Burung sekali!

Radio itu tidak akan mencapai Prancis.

Ada stasiun relay Siapkan di sepanjang pantai.

Sudah berakhir, Viktor.

Aku mengubahmu kepada penjaga negara.

Dan mereka akan berhati -hati sisanya.

Anda omong kosong nazi.

(DENGKUR)

Anda harus berhati -hati

Menarik senjata pada orang yang tidak Anda kenal.

Atau Anda akan menemukan diri Anda sendiri di atas kepala Anda

lebih cepat dari yang Anda harapkan.

SEN DOLAR: Gen?

Tidak semuanya seperti yang terlihat.

SEN DOLAR: Gen?

(Erangan)

SEN DOLAR: Apa yang terjadi Di sini?

Viktor: Dia mengambil langkah yang salah.

Kehilangan pijakannya. Saya hanya membantunya.

Bukankah itu benar?

(♪♪♪)

(Membuka pintu)

SEN DOLAR: Gen!

Tentang apa itu?

Saya memberi pria itu Manfaat dari keraguan, Penny.

Aku bersumpah aku melakukannya, tapi ...

-Penny: Apa? -Dia adalah mata -mata Nazi!

-WHO, Viktor? -Gene: Ya!

Saya menangkapnya menggunakan radio di kamarnya tadi malam.

-Sebuah radio? -Gene: Radio.

Uh, itu-- Ini adalah radio berukuran tas kerja.

Itu ada di kamarnya.

Dan sekarang sudah hilang.

Dan Anda melihat ini bagaimana?

Apakah Anda memata -matai dia?

Gene: Apa? TIDAK!

aku terbangun di tengah malam.

SEN DOLAR: Dan?

Dan saya pergi ke kamarnya.

Saya tahu itu.

Apa yang seharusnya saya lakukan, Sen dolar?

Apa yang harus saya lakukan?

-Abaikan saja? -Penny: Saya tahu itu.

Bagaimana kalau dia datang ke kamarku dengan senjata?

Berdiri di sana dengan pistol!

(Mencibir)

-Anda tidak percaya padaku. -Goodness, gen.

Gene: Apakah Anda percaya atau tidak?

SEN DOLAR: Gen, ayolah.

Apakah Anda percaya atau tidak?

Maksudku, kamu-- kamu hanya-- Anda harus tahu bagaimana suara -Nya.

Saya tidak menebusnya!

Saya tahu apa yang saya lihat!

(CELANA)

Saya minta maaf, Tapi saya tahu apa yang saya lihat.

SEN DOLAR: Gen, berhenti.

Saya tidak akan membuat ini. Aku berjanji padamu--

I-- Tidak apa-apa. Saya percaya Anda. Oke?

Saya percaya Anda.

Saya akan memeriksa dengan OSS.

Lihat apakah mereka memiliki sesuatu padanya.

Untukmu. Oke?

Bagus.

Terima kasih.

Kukira Saya harus memeriksa Viktor.

Mengapa?

Jaga musuh Anda lebih dekat, bukan?

Dan Anda membuat sendiri.

(♪♪♪)

(Membuka pintu)

SEN DOLAR: Saya sangat menyesal tentang semua itu.

Dia menjadi terpaku pada Anda.

Bahkan paranoid.

Dia sepertinya tidak sehat.

Dia tidak.

Saya khawatir dia akan pergi Lakukan sesuatu yang tidak rasional.

Saya hanya tidak memahaminya.

Mengapa dia mengatakan hal -hal ini tentangmu?

Sulit bagi siapa pun diri mereka sendiri dalam masa perang.

Ini, bukan?

Ya, itu benar.

Dia sudah mengintip demikian juga.

Saya pikir ada alasannya untuk percaya

Bahwa dia memiliki lebih banyak informasi dari yang dia pimpin.

Dipahami.

Penny, maafkan aku.

Tidak apa-apa.

Gene, itu OSS.

Saya membesarkan Viktor.

-Apakah semuanya baik -baik saja? -Penny: Ya, ya.

Aku hanya, um ...

Ada seorang tahanan di kantor lapangan.

Dia mungkin memiliki informasi di Viktor.

-Gene: Oh. -Jadi...

Gene: Haruskah saya masuk dan berbicara dengannya?

Tidak, tidak, tidak apa -apa. Saya mendapatkannya.

Saya hanya perlu Raih sarung tangan saya dengan sangat cepat.

(♪♪♪)

(Ciuman)

(Wirring mobil)

(♪♪♪)

(Wirring mobil)

(Menutup pintu)

(RINTIHAN)

(CELANA)

SERSAN MAYOR: Siapa yang kamu temui?

Siapa yang kamu temui?

(Erangan)

SERSAN MAYOR: Dimana file -file itu?

-Di mana, kamu omong kosong? -Penny: Sersan!

Tidak bisakah kamu melihat dia sudah cukup?

-Tapi Bu, saya diberitahu-- -Penny: Keluar!

-Ma'am, saya diberitahu untuk-- -Penny: Sekarang!

SERSAN MAYOR: Nazi Scumbag. Pengkhianat.

(Pintu ditutup dalam jarak)

Saya harus meminta maaf atas nama Sersan.

Dia ...

Nah, dia banyak melewati selama perang terakhir.

Dan saya pikir itu membuatnya Sedikit sadis.

Tapi sekarang dia sudah pergi, Dan kami sendirian,

Anda dan saya bisa mengobrol.

(Meniup udara)

Tepatnya apa yang kamu lakukan?

Gene: Tidak ada.

Sepertinya bukan apa -apa.

Ya, yah, apa yang kamu katakan?

Semuanya tidak seperti yang terlihat.

SEN DOLAR: Maaf membuat Anda menunggu sepanjang hari.

Jock: Tidak apa -apa.

Saya tetap sibuk.

Tetap.

Memberi saya kesempatan untuk menghabiskan Beberapa waktu turun di sekitar air.

Senang sesuatu yang baik datang darinya.

Hal yang lucu juga.

Saya benar -benar melihat perahu layar kepala pedalaman,

Tepat di sepanjang garis pantai.

Tepat di dekat tebing.

Tidak ada banyak pelaut Di sekitar sini?

Tentu.

Benar -benar tidak berlayar Saat ini tahun.

Terutama tidak di daerah itu.

Saya tidak mengatakan 'nothin' tentang seorang tamu,

Tapi truk Viktor itu Hilang hari ini,

Jadi mungkin Anda tahu sesuatu.

Pasangkan saya akan bertanya sedikit tentang itu.

Lihat apakah saya bisa mencari tahu siapa itu.

Hmm.

(♪♪♪)

Kotoran!

(Mengetuk pintu)

Halo?

(Mengklik telepon)

Gene: Tuhan sialan!

SEN DOLAR: Gen.

(Api berderak di latar belakang)

Hai.

Anda kembali.

SEN DOLAR: Ya, maaf. Saya-- Saya pikir Anda tertidur.

Tidak ingin membangunkanmu.

Apakah ada yang salah?

Saya melihat lampu.

Saya melihat lampu berkedip keluar di kejauhan.

Sepertinya seseorang sedang memberi sinyal atau sesuatu.

Saya-- Saya tidak bisa memahami itu.

Tapi saya pikir itu bahasa Jerman.

Ini tentang bertemu seseorang.

Apakah Jock berbicara bahasa Jerman?

TIDAK.

Nah, Anda tahu siapa yang mungkin melakukannya.

SEN DOLAR: Benar, um ...

Oke, eh ...

Apa?

Apa yang akan saya katakan sangat diklasifikasikan

dan tidak dapat diulang.

Saya berbicara dengan kantor pusat.

Beberapa hari yang lalu, dokumentasi tentang

Invasi Sekutu ke Eropa dikompromikan.

OSS dicegat pesan kode

dari mata -mata yang mencoba Dapatkan informasinya

di luar negeri.

Mereka melacaknya kembali ke dalam Beberapa mil dari kami.

Aku tahu.

Apa maksudmu kamu tahu?

Um, maksud saya hanya itu

Inilah yang saya coba Untuk memberitahumu, Penny,

tentang tidak mempercayai Viktor.

Benar.

Saya tidak percaya.

Yah, setidaknya ini memberitahu kita Dia bertemu mereka dan segera.

JADI...

Ayo temukan dia kalau begitu.

Tidak, tidak. Tunggu, tunggu.

I-- I-- Saya benar-benar berpikir ...

Saya pikir itu yang terbaik Bahwa kita menghabiskan waktu kita.

Mengapa?

SEN DOLAR: Nah, pesanan saya harus melihat siapa lagi yang terlibat.

Kami berpotensi mengungkap Cincin yang jauh lebih besar di sini.

Bagaimana dengan Bob dan Maude?

Apakah kita mencoba dan memperingatkan mereka?

Itu bisa menempatkan mereka dalam bahaya.

Saya pikir untuk saat ini Ini harus tetap di antara kita.

Telepon tidak ada.

-Apa? -The Lines dipotong.

-Di mana senjumu? -Gene: Dia mengambilnya.

Saya tidak tahu kapan, Tapi itu hilang.

SEN DOLAR: Bagaimana dengan senapan Bob?

Dia juga memilikinya.

Yah, kurasa kita harus tetap Kecerdasan Kami Tentang Kami

Sampai kita bisa mengetahuinya.

Jadi kita bertindak normal?

Seperti tidak ada yang salah.

(Mendesah)

Dimana Bob dan Maude? Apakah mereka sudah kembali?

SEN DOLAR: Kabut pasti menyimpannya di kota.

Mereka harus kembali kapan saja sekarang.

Tidak perlu khawatir dulu.

Gene: Pernahkah Anda melihatnya?

Dia di luar, memotong kayu.

Gene: Berapa lama itu?

10 menit yang lalu mungkin.

Sangat tenang di luar sana.

Mungkin kamu harus Pergi periksa dia.

Gene: Itu dia.

Apakah seseorang mencari saya?

Kata Penny Anda memotong kayu.

Ya.

Mencoba menemukan kapak.

Maksudmu yang ini?

Ya.

Bersembunyi di bayang -bayang.

Anda cukup baik dengan itu.

Apakah kamu datang ke sini hanya untuk mengawasi saya,

Atau Anda akan membantu?

Tentang kemarin.

Saya minta maaf tentang semua itu.

Saya tidak tahu apa yang masuk ke saya.

Pasti semua udara segar ini.

Mungkin itu kelelahan pertempuran.

Atau mungkin saja, Anda tahu,

umum Kebencian anti-imigran.

Bolehkah saya bertanya kepada Anda pertanyaan pribadi?

Apa pandangan Anda tentang fasisme?

Permisi?

Viktor: Apakah Anda menyukainya?

(Mencibir)

TIDAK.

Tidak terlalu suka.

Tidak ada yang berhubungan dengan?

Gene: Sulit menemukan landasan bersama

dengan orang yang mencoba untuk membunuhmu.

Membunuh teman -temanmu.

Mungkin bahkan keluargamu.

Bukankah begitu?

(Mendesah)

Saya merasakan pandangan saya harus sangat jelas.

Tidak terlalu suka.

Oh, itu kalian berdua.

Saya bertanya -tanya berapa lama Kalian berdua akan berada di luar sana.

Saya membuat Partridge untuk kami.

Maude bilang itu favoritmu, Viktor?

Viktor: Oh, betapa baik dirimu.

Ya.

Mohon permisi sejenak.

Bagaimana hasilnya? Apakah semuanya baik -baik saja?

Gene: Ya. Ya, saya tidak tahu.

Uh, hanya merasa seperti dia berada di--

(Mengetuk pintu)

Anda menunggu di sini. Saya akan- saya akan mendapatkannya.

Pagi, Bu.

Saya Sersan Milne.

Apakah Bob di sini?

Uh, tidak, tidak saat ini.

C-- Dapatkah saya membantu Anda?

Saya khawatir saya tidak di sini dengan kabar baik.

Itu atlet dan jocelyn.

Mereka ditemukan lebih awal Pagi ini di tebing.

Tapi sesuatu tidak bertambah di sini.

Itu tidak masuk akal.

Dan saya memang melihat beberapa lampu berkedip di sini

tadi malam juga.

Anda bertanya kepada saya, ada sesuatu yang tidak benar.

Ya Tuhan. Um ...

Hei, ada seorang polisi di pintu.

Dia meminta Paman Bob.

Mereka menemukan Tubuh Jock dan Jocelyn.

Astaga.

Lihat, tidak apa -apa. Tidak apa -apa.

Semuanya akan baik -baik saja.

Oke.

Penny: (di radio) seharusnya tidak lama.

Gen: (di radio) apakah Anda akan memberi tahu mereka tentang Viktor?

Penny: (di radio) ya, ini mengubah banyak hal.

kita perlu memberi tahu mereka apa yang kita ketahui.

Saya merasa tidak enak.

mungkin kita bisa menyelamatkan mereka dari monster itu.

Gen: (di radio) sen, tidak, tidak, tidak. ini bukan salahmu.

Anda tidak tahu dia akan lakukan sesuatu seperti ini.

SEN DOLAR; (Di radio) lebih baik saya pergi.

petugas sedang menunggu.

(♪♪♪)

(♪♪♪)

Penny Go?

Gene: Ya, dia pergi ke Bantu teman Bob.

Viktor: Masih belum ada tanda -tanda Bob dan Maude?

TIDAK.

(Viktor scrunch)

Jadi hanya kita sekarang.

(♪♪♪)

Gen.

Gene: Sen dolar.

Saya pikir Anda ...

SEN DOLAR: Astaga.

Itu Petugas Milne.

Viktor.

(♪♪♪)

(CELANA)

SEN DOLAR: Saya sangat menyesal, Gene.

Saya seharusnya mempercayai Anda.

(♪♪♪)

Dia telah disembunyikan di gudang.

Apa yang kita lakukan sekarang?

Kamu benar.

Kami membutuhkan penjaga negara.

Anda menjaga ini dengan aman.

Saya menuju ke kota.

Viktor: Gen!

Membantu!

Gen!

Membantu!

Membantu!

Gen!

Gene: Siapa kamu?

Benar-benar?

Setidaknya beri tahu saya Mengapa Anda melakukan ini.

Melakukan apa?

Menghancurkan kehidupan orang.

Mengapa Anda melakukan ini untuk keluarga ini?

Ke Penny?

Apa gunanya?

Anda sepertinya sudah tahu APA SAYA.

Mata -mata.

Untuk BUMN Inggris.

Anda benar -benar mengharapkan saya percaya itu?

TIDAK.

Bahkan jika Anda melakukannya, sudah terlambat.

Gene: Mengapa?

Apa yang tidak kamu katakan padaku?

(Pintu terbuka dan menutup JARAK)

Tetap diam.

Sen dolar.

Saya sangat menyesal Bahwa kami tidak kembali.

Kami-- Kami harus menginap di malam hari di kota setelah pelelangan

Karena ada begitu banyak kabut.

Tidak apa -apa. Um ...

Maaf, saya D-- Saya tidak tahu bagaimana cara memberi tahu Anda.

Anda lihat, Gene. Duduk.

Gene: L-- lihat, sesuatu terjadi dan ...

Bob: Gene, kataku duduk.

(♪♪♪)

Bob: Kami berbicara dengan Penny.

Sudah waktunya kita berbicara sedikit.

Um, Gene.

Bob dan saya perlu berbicara dengan Anda tentang Penny.

Dan perasaanmu untuknya.

Apakah kamu benar -benar mencintainya dengan seluruh hati dan jiwa Anda?

Tanpa syarat?

Itulah yang perlu kita ketahui.

Ya, Bu, tentu saja.

Dan Anda akan melakukan apapun untuknya?

Dan keluarganya?

Uh, maafkan aku. Apa yang kamu katakan?

Uh, Maude.

Gen, apakah kamu akrab dengan istilah pietas?

Itu berarti komitmen,

tugas untuk keluarga seseorang dan leluhur.

Dan dalam beberapa budaya, Terutama milik kita,

itu dipandang sebagai yang sangat penting tanggung jawab.

Dan jika Anda melakukannya Bergabunglah dengan keluarga kami,

itu perlu berarti sesuatu untukmu juga.

Gen, apa yang kamu tahu Bund Jerman-Amerika?

Hanya saja mereka ditutup sebelum perang.

Nah, secara resmi.

Tapi ada beberapa yang bertengkar untuk penyebabnya.

Maksudmu fasisme?

Bob: Oh.

Kami akui itu memang Cincin jahat untuk itu hari ini.

Ya, karena itu harus.

UNGU MUDA: Tidak, tapi, gen, ini tentang jauh lebih dari itu.

Itu adalah sistem yang menjanjikan Kembalikan apa yang hilang,

untuk membangun sesuatu yang lebih besar.

Ini tentang melestarikan cara hidup yang ditinggikan.

Bob: Anda membuang -buang waktu.

Sudah kubilang dia tidak punya tulang belakang untuk itu.

Gene, apakah Anda tahu bahwa saya bertarung Melawan Fritz Kuhn di Prancis?

Saya berjuang melawannya.

Dan dia pria yang baik.

Dia pria yang hebat.

Dia seorang pria dengan masa depan di matanya.

Apakah Anda tertarik Di masa depan?

Amerika Serikat pergi ke barat.

Sumbu akan ke timur.

Sumbu akan memenangkan perang.

Apakah Anda mengerti itu?

Begitulah keadaannya di alam.

Anda adalah bagian dari ini.

Dan Anda juga bisa.

Anda bisa menjadi bagian dari sejarah.

Bund terbuka untuk semua,

Asalkan Anda tulus dan karakter yang baik.

Aku tahu kamu Semua hal ini, gen.

Tolong jangan beri tahu saya

Bahwa saya terlalu tinggi Komitmen Anda untuk Penny

Dan semua yang dia yakini.

Sen dolar?

Sen kami yang indah.

Sejak dia masih kecil, Ketika ibunya terbukti tidak layak,

Kami melakukan pendidikannya tentang hal -hal moral,

Spiritual, Fisik, intelektual.

Beberapa orang Hanya tidak memiliki apa yang diperlukan.

Gene, saya melihat rasa sakit Anda.

Saya melihat perjuangan Anda dengan rasa malu dan keragu -raguan.

Dan Anda bertarung dalam perang itu, Anda berkorban begitu banyak di--

Maude, berhenti mengalahkannya sampai mati.

Tidak, ini waktu Anda untuk menemukan keberanian Anda.

Ada tempat untukmu di sini.

Bangkit dan menjadi pahlawan perjalanan Anda sendiri.

Oh, berhentilah mengalahkannya sampai mati!

Anda membuat pilihan Anda!

Anda bukan manusia yang cukup.

Ya, lari, kau pengecut.

Apa yang saya katakan?

Apa yang saya katakan?

(CELANA)

Quinn, terima kasih Tuhan kamu di sini.

Penny, kamu kembali.

Lihat, saya tidak tahu Apa yang terjadi di sini,

tapi itu--- itu-- Ini Bob dan Maude,

dan mereka-- dan mereka ...

Itu dia.

Collins, Quinn, Itu Gene Weber.

-Tulah mata -matanya. -Gene: Oh, tidak.

Collins: Kapten, dia benar.

Saya menemukan mayat Petugas Milne.

Quinn: Tahan, Gene!

Anda lebih baik tinggal di sana.

Dengar, Nak, tetap tenang. Jangan lakukan sesuatu yang bodoh.

Saatnya Anda pergi dengan tenang.

Saya sedang diatur. Quinn, kamu kenal aku.

Anda tahu OSS mengirim saya ke sini untuk menyelidiki.

Saya tidak tahu apa yang dia katakan, Tapi dengarkan aku.

Anda tahu siapa saya.

SEN DOLAR: Kami tahu cerita sampul Anda.

FBI telah berhubungan dengan OSS.

Mereka tidak tahu siapa Anda atau siapa McVean.

Apakah dia kontak Nazi Anda?

Penny, tidak. Penny, tidak (ucapan yang tumpang tindih)

SEN DOLAR: Gen, memiliki apapun yang Anda katakan sudah benar?

Lepaskan aku! Lepaskan aku!

-Sen dolar! -Quinn: Collins!

Gene: Sen dolar! Sen dolar! Sen dolar!

(Erangan)

Masuk ke truk, anak laki -laki.

Collins: Ayo. Ayo pergi.

Quinn: Saya perlu turun ke markas besar.

Sebenarnya, OSS menginginkannya kembali.

Saya telah diperintahkan untuk mengirimkannya mereka ke Washington segera.

Anda menguncinya.

Lanjutkan penyelidikan.

Tentu.

Terima kasih, Quinn.

Saya sangat ingin memasukkan ini tangan yang aman.

Semoga beruntung.

(♪♪♪)

Bob: Itu tidak berjalan sesuai rencana.

Sayang, kamu baik -baik saja?

Saya berpikir pasti Dia adalah orangnya.

Bob: Dia membuat pilihannya.

Aku sangat menyesal hatinya tidak cukup murni.

SEN DOLAR: Aku mencintainya.

Maude: Tidak apa -apa. Tidak apa -apa.

Penyebabnya lebih dulu.

Tentu saja.

Itu tidak dimaksudkan.

Saya telah melakukan kontak dengan teman -teman Jerman kami.

Mereka akan segera datang ke sini transaksi.

Saya akan menghadapinya.

Kemasi barang -barang Anda dan pergi ke pondok.

Anda akan aman di sana.

Viktor bisa berlayar saya ke titik pertemuan.

Jika kita terburu -buru, kita masih bisa membuatnya handoff.

(Mendesah)

Apalagi dia.

Aku tidak bisa lebih bangga padamu.

(♪♪♪)

(Maude Sighs)

(Erangan)

Quinn: Bagaimana perasaanmu, nak?

Kamu baik -baik saja?

Maaf tentang semua itu.

Melakukan apa yang harus kami pastikan Anda keluar dari sana

dalam keadaan utuh.

Untungnya, Viktor memiliki rakyatnya Radio kami tepat pada waktunya.

Collins: Ternyata Dia bekerja menyamar.

Quinn: Ya, saya sendiri tidak percaya pada awalnya.

Tapi OSS mengkonfirmasi pagi ini.

Dia menyelamatkan hidupmu.

Jadi kemana kamu membawaku?

Quinn: Kembali ke markas.

McVean ingin membawa Anda masuk untuk pembekalan.

Bagaimana dengan file -file itu? Seluruh misi?

Quinn: Viktor mengurusnya.

Dia menemukan dokumen yang sebenarnya Tersembunyi di suatu tempat di gudang.

Menukar mereka dengan yang palsu.

Collins: Bob menggunakan lukisannya

sebagai cara untuk berkomunikasi kohort Nazi -nya.

Poin penghindaran, seluruh kesepakatan.

Anda hanya akan membiarkan Bob dan Maude lolos begitu saja?

Quinn: Tentu saja tidak.

Orang -orang saya bekerja dengan OSS Saat kita berbicara.

Harus menjatuhkan mereka segera

Sebelum mereka mencapai pondok mereka untuk pertemuan.

Kami punya laporan perahu layar di lepas pantai.

Viktor diikat sekarang.

Dia bebek yang duduk sampai saat itu.

Kita harus kembali.

Quinn: Gene, kamu baik -baik saja.

Tapi untuk saat ini, pekerjaan Anda di sini selesai.

Duduk saja dengan ketat.

Collins: Dan jangan khawatir.

Tunangan Anda akan menjawab untuk apa yang dia lakukan.

Kami akan memastikannya.

Tidak akan terjadi sebatang rokok.

Cahaya?

(Mendengus)

Gen!

(Mendengus)

Hentikan truk!

Tinggal kembali!

Quinn: Tenang saja sekarang, Nak.

Kami tidak bisa membiarkannya berakhir seperti ini.

Sudah kubilang itu sedang diurus.

Kita tidak bisa membiarkannya berakhir seperti ini!

Biarkan aku kembali.

Tolong, biarkan saya kembali.

Bergerak.

Pikirkan Anda benar -benar licik, ya?

Anda benar -benar berpikir saya tidak tahu

bahwa Anda sudah di atas sana di radio

Di tengah malam?

Saya hanya mencoba untuk mencapai keluargaku.

Anda akan berlayar saya ke titik pertemuan saya,

atau saya berjanji kepada Anda Gestapo akan mencapai keluarga Anda

sebelum Anda melakukannya.

(♪♪♪)

SEN DOLAR: Terus bergerak. Hampir sampai.

(SUARA TEMBAKAN)

Penny, biarkan dia pergi.

SEN DOLAR: Jika dia mati, begitu pula alibi Anda.

Dia satu -satunya siapa yang bisa menjaminmu.

Penny, dengarkan aku.

Jatuhkan pistol!

Ini bukan kamu. Dengarkan aku.

Anda tidak tahu siapa saya.

Jatuhkan pistol!

Oke.

Oke.

Bagaimana Anda bisa melakukan ini? Saya hanya tidak mengerti.

Karena saya percaya!

Saya menginginkan yang terbaik Untuk orang -orang di negara ini!

Apa yang dimiliki pemerintah memberi kami?

Begitu banyak nyawa muda yang hilang saat perang?

Siapa sebenarnya musuh?

Bob dan Maude.

Apa?

Mereka membunuh ibumu, Penny.

Saya minta maaf.

Anda tidak tahu Apa yang Anda bicarakan.

Gene: Penny, tunggu. Tunggu saja, oke?

Dengar, Penny, dengarkan aku.

Letakkan pistolnya. Biarkan dia pergi.

Ini belum terlambat. Silakan.

Penny, saya bisa membantu Anda.

Aku sangat mencintaimu.

Aku mencintaimu.

(Tembakan)

(Erangan)

Gene: Hei, kamu baik -baik saja?

Hai.

Saya minta maaf.

Saya akan membutuhkan bantuan. Tetap bertahan. Di Sini.

Pergi.

(♪♪♪)

(♪♪♪)

Gene: Sen dolar?

Saya tidak percaya kita harus berlari dari rumah kita seperti pengungsi.

-Tenang. -BOB.

Kami akan aman di pondok Sebelum Anda menyadarinya.

-Maude: Bob, cepat! -State Guard: Pak!

(CELANA)

-State Guard: Freeze! -Maude: Oh.

(SUARA TEMBAKAN)

(DENGKUR)

Sen dolar.

(DENGKUR)

(♪♪♪)

SEN DOLAR: Saya terkadang mengalami mimpi buruk

(SUARA TEMBAKAN)

SEN DOLAR: Bahwa Jerman menangkapmu dan menempatkan Anda di sebuah kamp.

terkadang lebih buruk.

terkadang dalam mimpi, Aku berteriak untukmu

untuk melakukan apa pun itu Anda perlu melakukannya.

untuk bergabung dengan mereka.

untuk melakukan apa yang harus Anda lakukan untuk tetap hidup.

(Fire Crockling)

(♪♪♪)

McVean: Kami memiliki kecurigaan tentang duncolms,

Tapi diberi tempat Penny di OSS,

Itu adalah klaim berbahaya.

Dan sayangnya,

Anda adalah satu -satunya cara kami Cari tahu kebenarannya.

Dibutuhkan jenis tertentu orang untuk melakukan itu.

Untuk hidup bohong,

hari demi hari.

Saya hanya bisa membayangkan

rasa pengkhianatan Anda harus merasakan.

Jelas, kami Menyapu seluruh cobaan ini

di bawah permadani.

Anda harus mematuhi Kisah resmi, tentu saja.

Anda melayani negara Anda dengan baik.

Anda harus bangga.

Dari apa yang bisa kita duga,

Bob sedang memetakan daerah sekitarnya

untuk situs invasi potensial.

Kira dia mengira lukisan akan kurang mencurigakan

dari foto.

Saya kira dia benar.

Jika ada sesuatu kita bisa melakukan ...

Ada.

Seorang pria yang sangat berani yang saya kenal, Keluarganya terjebak di luar negeri.

Dia menyelamatkan hidupku.

McVean: kami akan melakukan apa yang kami bisa.

(♪♪♪)

(Isak tangis)

(♪♪♪)

(♪♪♪)

Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.